"""
CircuitPython Program for LED Brightness Control on ESP32-C3 Supermini
===============================================================
This program controls the brightness of an LED connected to IO0 using two buttons (B1 on IO1, B2 on IO2).
Short press:
    - B1: Turns the LED on with the stored brightness level.
    - B2: Turns the LED off.
Long press (>= 0.5s):
    - B1: Increases the brightness in 15 steps, doubling each step every 500ms.
    - B2: Decreases the brightness in 15 steps, halving each step every 500ms.
The brightness level is stored and restored after turning off and on the LED.
"""

import pwmio
import board
import digitalio
import time

# Initialize PWM output on IO0 for the LED
led = pwmio.PWMOut(board.IO0, frequency=1000, duty_cycle=0)

# Initialize buttons on IO1 and IO2
button1 = digitalio.DigitalInOut(board.IO1)
button1.direction = digitalio.Direction.INPUT
button1.pull = digitalio.Pull.UP

button2 = digitalio.DigitalInOut(board.IO2)
button2.direction = digitalio.Direction.INPUT
button2.pull = digitalio.Pull.UP

# State variables
button1_press_time = 0
button2_press_time = 0
button1_counter = 0
button2_counter = 0

# Brightness control variables
brightness_levels = [int(65535 / (2 ** (15 - i))) for i in range(15)]
brightness_index = 0
led.duty_cycle = brightness_levels[brightness_index]

# Check button press function
def check_button_press():
    global button1_press_time, button2_press_time, button1_counter, button2_counter
    current_time = time.monotonic()

    # Check button1 (B1)
    if not button1.value:  # Button1 pressed
        if button1_press_time == 0:
            button1_press_time = current_time
        button1_counter += 1
        if button1_counter >= 10:  # Check every 500 ms (50 ms * 10)
            handle_long_press(button1)
            button1_counter = 0
    else:
        if button1_press_time != 0:
            press_duration = current_time - button1_press_time
            if press_duration < 0.5:
                handle_short_press(button1)
            button1_press_time = 0
            button1_counter = 0

    # Check button2 (B2)
    if not button2.value:  # Button2 pressed
        if button2_press_time == 0:
            button2_press_time = current_time
        button2_counter += 1
        if button2_counter >= 10:  # Check every 500 ms (50 ms * 10)
            handle_long_press(button2)
            button2_counter = 0
    else:
        if button2_press_time != 0:
            press_duration = current_time - button2_press_time
            if press_duration < 0.5:
                handle_short_press(button2)
            button2_press_time = 0
            button2_counter = 0

# Handle short press
def handle_short_press(button):
    if button == button1:
        turn_on_led()
    elif button == button2:
        turn_off_led()

# Handle long press
def handle_long_press(button):
    if button == button1:
        increase_brightness()
    elif button == button2:
        decrease_brightness()

# LED control functions
def turn_on_led():
    global led
    led.duty_cycle = brightness_levels[brightness_index]
    print(f"LED turned on with brightness level: {brightness_levels[brightness_index]}")

def turn_off_led():
    global led
    led.duty_cycle = 0
    print("LED turned off.")

def increase_brightness():
    global brightness_index, led
    if brightness_index < 14:
        brightness_index += 1
        led.duty_cycle = brightness_levels[brightness_index]
        print(f"Increasing brightness to {brightness_levels[brightness_index]}")

def decrease_brightness():
    global brightness_index, led
    if brightness_index > 0:
        brightness_index -= 1
        led.duty_cycle = brightness_levels[brightness_index]
        print(f"Decreasing brightness to {brightness_levels[brightness_index]}")

# Main loop to check button presses
while True:
    check_button_press()
    time.sleep(0.05)  # 50 ms delay for button sampling

